@@ -48,6 +48,7 @@ echo "bcmath found at: ${BCMATH_EXT}"
 IMAGICK_OR_GD="-dextension=gd.so"
 JSON_EXT="-dextension=json.so"
 XML_EXT="-dextension=xml.so"
+CURL_EXT="-dextension=curl.so"
 if [ "$(${PHP_BINARY} -r 'echo PHP_MAJOR_VERSION;')" = "5" ];then
 
     # 5.5, 5.4, 5.3
@@ -87,6 +88,7 @@ for file in $EXAMPLE_FILES; do
         ${BCMATH_EXT} \
         ${JSON_EXT} \
         ${XML_EXT} \
+        ${CURL_EXT} \
         -d display_errors=on \
         -d error_reporting=-1 \
         -d memory_limit=1G \
@@ -190,4 +192,4 @@ cd - > /dev/null
 rm -rf "${TEMP_FOLDER}"
 
 echo "Exit code: ${FAILED_FLAG}"
-exit "${FAILED_FLAG}"
\ No newline at end of file
+exit "${FAILED_FLAG}"
